import cv2

from py_doc.yolov7.document_detection import detect_document

class Document:
    """
    A class for representing documents.

    :param name: The name of the document.
    :type name: str
    """

    def __init__(self, name):
        self.name = name

    def get_name(self):
        """
        Get the name of the document.

        :return: The name of the document.
        :rtype: str
        """

        return self.name

    def get_bounding_box(self):
        """
        Use an object detection model to get bounding boxes for titles, text, figures, lists, and tables in the document.

        :return: A list of bounding boxes of the document.
        :rtype: list
        """
        image = cv2.imread(self.name)
        return detect_document(image)

    def draw_classifications(self, file):
        """
        Draw the bounding boxes on the document.

        :param file: The output file to save the image to.
        :type file: str

        :return: Boolean indicating if the image was saved.
        :rtype: bool
        """
        
        image = cv2.imread(self.name)
        bboxes = self.get_bounding_box()

        for bbox in bboxes:
            cv2.rectangle(image, (bbox[0], bbox[1]), (bbox[2], bbox[3]), (255, 0, 0), 2)

        return cv2.imwrite(file, image)



if __name__ == "__main__":
    document = Document("/home/connor/Development/MachineLearning/document-platform/py-doc/py_doc/yolov7/test.jpg")
    print(document.get_bounding_box())
    